@@ -39,6 +39,14 @@ enum
   LAST_PROPERTY
 };
 
+enum
+{
+  SIG_HAS_CONNECTIONS_CHANGED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 /* Minimum time before 2 publishing (in seconds) */
 #define PUBLISH_THROTTLE 10
 
@@ -49,6 +57,7 @@ struct _PositionPublisherPrivate
 {
   ConnectionWatcher *watcher;
   LocationGPSDevice *gps_device;
+  /* List of (TpConnection *) supporting location publishing */
   GSList *connections;
   GHashTable *location;
   /* If not 0, we are waiting before publishing again */
@@ -80,6 +89,12 @@ remove_connection (PositionPublisher *self,
       self);
   priv->connections = g_slist_remove (priv->connections, conn);
   g_object_unref (conn);
+
+  if (g_slist_length (priv->connections) == 0)
+    {
+      g_print ("We don't have location connection any more\n");
+      g_signal_emit (self, signals[SIG_HAS_CONNECTIONS_CHANGED], 0, FALSE);
+    }
 }
 
 static void
@@ -133,16 +148,8 @@ publish_to_conn (PositionPublisher *self,
   if (priv->location == NULL)
     return;
 
-  if (priv->throttle_timeout != 0)
-    /* We are waiting */
-    return;
-
   tp_cli_connection_interface_location_call_set_location (conn, -1,
       priv->location, set_location_cb, NULL, NULL, G_OBJECT (self));
-
-  /* We won't publish during the next PUBLISH_THROTTLE seconds */
-  priv->throttle_timeout = g_timeout_add_seconds (PUBLISH_THROTTLE,
-      publish_throttle_timeout_cb, self);
 }
 
 static void
@@ -151,12 +158,20 @@ publish_to_all (PositionPublisher *self)
   PositionPublisherPrivate *priv = POSITION_PUBLISHER_GET_PRIVATE (self);
   GSList *l;
 
+  if (priv->throttle_timeout != 0)
+    /* We are waiting */
+    return;
+
   for (l = priv->connections; l != NULL; l = g_slist_next (l))
     {
       TpConnection *conn = l->data;
 
       publish_to_conn (self, conn);
     }
+
+  /* We won't publish during the next PUBLISH_THROTTLE seconds */
+  priv->throttle_timeout = g_timeout_add_seconds (PUBLISH_THROTTLE,
+      publish_throttle_timeout_cb, self);
 }
 
 static void
@@ -242,6 +257,13 @@ connection_added_cb (ConnectionWatcher *watcher,
 
   priv->connections = g_slist_prepend (priv->connections, g_object_ref (conn));
 
+  if (g_slist_length (priv->connections) == 1)
+    {
+      /* We just added the first connection */
+      g_print ("We have location connection\n");
+      g_signal_emit (self, signals[SIG_HAS_CONNECTIONS_CHANGED], 0, TRUE);
+    }
+
   g_signal_connect (conn, "invalidated",
       G_CALLBACK (conn_invalidated_cb), self);
 
@@ -305,6 +327,16 @@ position_publisher_class_init (PositionPublisherClass *position_publisher_class)
       G_PARAM_CONSTRUCT | G_PARAM_WRITABLE | G_PARAM_READABLE
       | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_BLUR, param_spec);
+
+  signals[SIG_HAS_CONNECTIONS_CHANGED] = g_signal_new (
+      "has-connections-changed",
+      G_OBJECT_CLASS_TYPE (object_class),
+      G_SIGNAL_RUN_LAST,
+      0,
+      NULL, NULL,
+      g_cclosure_marshal_VOID__BOOLEAN,
+      G_TYPE_NONE,
+      1, G_TYPE_BOOLEAN);
 }
 
 void
@@ -404,3 +436,11 @@ position_publisher_set_blur (PositionPublisher *self,
   priv->blur = blur;
   g_object_notify (G_OBJECT (self), "blur");
 }
+
+gboolean
+position_publisher_has_connections (PositionPublisher *self)
+{
+  PositionPublisherPrivate *priv = POSITION_PUBLISHER_GET_PRIVATE (self);
+
+  return g_slist_length (priv->connections) > 0;
+}
